@@ -170,7 +170,8 @@ class Insights:
             f""
             f"SELECT * "
             f"FROM sessions "
-            f"WHERE session_date >= {self.bar_start_date}"
+            f"WHERE session_date >= '{self.bar_start_date}' "
+            f";"
         )
         logger.info(data)
         for row in data:
@@ -181,7 +182,8 @@ class Insights:
             f""
             f"SELECT * "
             f"FROM poms "
-            f"WHERE poms_date >= {self.heatmap_start_date}"
+            f"WHERE poms_date >= '{self.heatmap_start_date}' "
+            f";"
         )
         logger.info(data)
         for row in data:
